==> zio-aws-kms_2.13-5.17.104.11-sources.jar: zio/aws/kms/model/AliasListEntry.scala <==
package zio.aws.kms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kms.model.primitives.{
  DateType,
  KeyIdType,
  ArnType,
  AliasNameType
}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class AliasListEntry(
    aliasName: Option[AliasNameType] = None,
    aliasArn: Option[ArnType] = None,
    targetKeyId: Option[KeyIdType] = None,
    creationDate: Option[DateType] = None,
    lastUpdatedDate: Option[DateType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kms.model.AliasListEntry = {
    import AliasListEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kms.model.AliasListEntry
      .builder()
      .optionallyWith(
        aliasName.map(value => AliasNameType.unwrap(value): java.lang.String)
      )(_.aliasName)
      .optionallyWith(
        aliasArn.map(value => ArnType.unwrap(value): java.lang.String)
      )(_.aliasArn)
      .optionallyWith(
        targetKeyId.map(value => KeyIdType.unwrap(value): java.lang.String)
      )(_.targetKeyId)
      .optionallyWith(
        creationDate.map(value => DateType.unwrap(value): Instant)
      )(_.creationDate)
      .optionallyWith(
        lastUpdatedDate.map(value => DateType.unwrap(value): Instant)
      )(_.lastUpdatedDate)
      .build()
  }
  def asReadOnly: zio.aws.kms.model.AliasListEntry.ReadOnly =
    zio.aws.kms.model.AliasListEntry.wrap(buildAwsValue())
}
object AliasListEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kms.model.AliasListEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kms.model.AliasListEntry =
      zio.aws.kms.model.AliasListEntry(
        aliasName.map(value => value),
        aliasArn.map(value => value),
        targetKeyId.map(value => value),
        creationDate.map(value => value),
        lastUpdatedDate.map(value => value)
      )
    def aliasName: Option[AliasNameType]
    def aliasArn: Option[ArnType]
    def targetKeyId: Option[KeyIdType]
    def creationDate: Option[DateType]
    def lastUpdatedDate: Option[DateType]
    def getAliasName: ZIO[Any, AwsError, AliasNameType] =
      AwsError.unwrapOptionField("aliasName", aliasName)
    def getAliasArn: ZIO[Any, AwsError, ArnType] =
      AwsError.unwrapOptionField("aliasArn", aliasArn)
    def getTargetKeyId: ZIO[Any, AwsError, KeyIdType] =
      AwsError.unwrapOptionField("targetKeyId", targetKeyId)
    def getCreationDate: ZIO[Any, AwsError, DateType] =
      AwsError.unwrapOptionField("creationDate", creationDate)
    def getLastUpdatedDate: ZIO[Any, AwsError, DateType] =
      AwsError.unwrapOptionField("lastUpdatedDate", lastUpdatedDate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kms.model.AliasListEntry
  ) extends zio.aws.kms.model.AliasListEntry.ReadOnly {
    override val aliasName: Option[AliasNameType] = scala
      .Option(impl.aliasName())
      .map(value => zio.aws.kms.model.primitives.AliasNameType(value))
    override val aliasArn: Option[ArnType] = scala
      .Option(impl.aliasArn())
      .map(value => zio.aws.kms.model.primitives.ArnType(value))
    override val targetKeyId: Option[KeyIdType] = scala
      .Option(impl.targetKeyId())
      .map(value => zio.aws.kms.model.primitives.KeyIdType(value))
    override val creationDate: Option[DateType] = scala
      .Option(impl.creationDate())
      .map(value => zio.aws.kms.model.primitives.DateType(value))
    override val lastUpdatedDate: Option[DateType] = scala
      .Option(impl.lastUpdatedDate())
      .map(value => zio.aws.kms.model.primitives.DateType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kms.model.AliasListEntry
  ): zio.aws.kms.model.AliasListEntry.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kms_2.13-5.17.174.1-sources.jar: zio/aws/kms/model/AliasListEntry.scala <==
package zio.aws.kms.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.kms.model.primitives.{
  DateType,
  KeyIdType,
  ArnType,
  AliasNameType
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class AliasListEntry(
    aliasName: Optional[AliasNameType] = Optional.Absent,
    aliasArn: Optional[ArnType] = Optional.Absent,
    targetKeyId: Optional[KeyIdType] = Optional.Absent,
    creationDate: Optional[DateType] = Optional.Absent,
    lastUpdatedDate: Optional[DateType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kms.model.AliasListEntry = {
    import AliasListEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kms.model.AliasListEntry
      .builder()
      .optionallyWith(
        aliasName.map(value => AliasNameType.unwrap(value): java.lang.String)
      )(_.aliasName)
      .optionallyWith(
        aliasArn.map(value => ArnType.unwrap(value): java.lang.String)
      )(_.aliasArn)
      .optionallyWith(
        targetKeyId.map(value => KeyIdType.unwrap(value): java.lang.String)
      )(_.targetKeyId)
      .optionallyWith(
        creationDate.map(value => DateType.unwrap(value): Instant)
      )(_.creationDate)
      .optionallyWith(
        lastUpdatedDate.map(value => DateType.unwrap(value): Instant)
      )(_.lastUpdatedDate)
      .build()
  }
  def asReadOnly: zio.aws.kms.model.AliasListEntry.ReadOnly =
    zio.aws.kms.model.AliasListEntry.wrap(buildAwsValue())
}
object AliasListEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kms.model.AliasListEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kms.model.AliasListEntry =
      zio.aws.kms.model.AliasListEntry(
        aliasName.map(value => value),
        aliasArn.map(value => value),
        targetKeyId.map(value => value),
        creationDate.map(value => value),
        lastUpdatedDate.map(value => value)
      )
    def aliasName: Optional[AliasNameType]
    def aliasArn: Optional[ArnType]
    def targetKeyId: Optional[KeyIdType]
    def creationDate: Optional[DateType]
    def lastUpdatedDate: Optional[DateType]
    def getAliasName: ZIO[Any, AwsError, AliasNameType] =
      AwsError.unwrapOptionField("aliasName", aliasName)
    def getAliasArn: ZIO[Any, AwsError, ArnType] =
      AwsError.unwrapOptionField("aliasArn", aliasArn)
    def getTargetKeyId: ZIO[Any, AwsError, KeyIdType] =
      AwsError.unwrapOptionField("targetKeyId", targetKeyId)
    def getCreationDate: ZIO[Any, AwsError, DateType] =
      AwsError.unwrapOptionField("creationDate", creationDate)
    def getLastUpdatedDate: ZIO[Any, AwsError, DateType] =
      AwsError.unwrapOptionField("lastUpdatedDate", lastUpdatedDate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kms.model.AliasListEntry
  ) extends zio.aws.kms.model.AliasListEntry.ReadOnly {
    override val aliasName: Optional[AliasNameType] = zio.aws.core.internal
      .optionalFromNullable(impl.aliasName())
      .map(value => zio.aws.kms.model.primitives.AliasNameType(value))
    override val aliasArn: Optional[ArnType] = zio.aws.core.internal
      .optionalFromNullable(impl.aliasArn())
      .map(value => zio.aws.kms.model.primitives.ArnType(value))
    override val targetKeyId: Optional[KeyIdType] = zio.aws.core.internal
      .optionalFromNullable(impl.targetKeyId())
      .map(value => zio.aws.kms.model.primitives.KeyIdType(value))
    override val creationDate: Optional[DateType] = zio.aws.core.internal
      .optionalFromNullable(impl.creationDate())
      .map(value => zio.aws.kms.model.primitives.DateType(value))
    override val lastUpdatedDate: Optional[DateType] = zio.aws.core.internal
      .optionalFromNullable(impl.lastUpdatedDate())
      .map(value => zio.aws.kms.model.primitives.DateType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kms.model.AliasListEntry
  ): zio.aws.kms.model.AliasListEntry.ReadOnly = new Wrapper(impl)
}
